@@ -54,7 +54,7 @@ def tox_testenv_create(venv, action):
     .. note:: This hook uses ``firstresult=True`` (see `pluggy first result only`_) -- hooks
         implementing this will be run until one returns non-``None``.
 
-    .. _`pluggy first result only`: http://pluggy.readthedocs.io/en/latest/#first-result-only
+    .. _`pluggy first result only`: https://pluggy.readthedocs.io/en/latest/#first-result-only
     """
 
 
@@ -115,3 +115,8 @@ def tox_runenvreport(venv, action):
     This could be used for alternative (ie non-pip) package managers, this
     plugin should return a ``list`` of type ``str``
     """
+
+
+@hookspec
+def tox_cleanup(session):
+    """Called just before the session is destroyed, allowing any final cleanup operation"""
